==> webStore_2.8.8_estable.zip: README.md <==
***** Version inicial 2.8.0
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 1 (2.8.1)
	- La funcin remota es la encargada de lanzar los widgets a actualizar. Hasta ahora lo haca cada "remoteXxxxxx" de cada clase
		Y eso obligaba al programador a repetir lo mismo SIEMPRE
	- Creada la clase Email con su funcionalidad bsica
	- Clase Email enva emails directamente o desde funcin remota (Ajax)
	- Terminado un apartado de contacto actualizando el widget actual
	- Actualizada clase de usuario para aadir varias funciones estticas:
		1 Chequeo de que el usuario existe utilizando el email
		2 Registro del usuario en la BD
		3 Login de usuario
	- Preparamos una versin previa del registro
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 2 (2.8.2)
	- Creacin de gestin bsica de mdulos (sin admin)
		- Control de acciones ==> las acciones se guardan en un fichero llamado actions.php para cada mdulo.
	-(luna de papel) Se crean mdulos para login, registro y recuperar contrasea. Por ahora slo se registran las aciones
		de dichos mdulos
	-Aadimos a la clase Usuario las funciones necesarias para hacer login, registro y recuperacin de contrasea
	-Aadimos a la clase Sesion una propiedad esttica que consiste en un array dnde guardaremos los pares variable => valor
		y usaremos este arrya cuando haya que recargar la pgina para adir dichas variables como get (?variable=valor)
	-Aadimos los get/insert/delete/isset de dichas variables
	-El control de secciones se hace ahora desde la clase de secciones y no es necesario utilizar el fichero sectionControl
	-La carga dinmica se hace ahora por tema para que la cach sea independiente para cada instancia de webStore
	-Las clases y mtodos se pueden sobre escribir en el tema y en todo webStore
	-Se crean variables para indicar dnde est la carpeta css
	-Se mejora el proceso de minificacin de CSS creando una funcin comn
	-Se crea el tema Admin fuera de la carpeta Themes para administrar WebStore
	-Se crea en Admin la opcin para subir imgenes
	-La subida de datos se almacenar, a partir de ahora en la carpeta update. Dentro de esta carpeta se almacenarn los
		ficheros segn su tipo (imagenes, videos, pdf, etc.)
	-Modificacin en la clase Banner que permite mostrar una imagen independientemente de que est o no en un banner
	-Modificacin en la clase Banner para que se pueda eliminar una imagen siempre que no est en un banner y se le hace un 
		acceso remoto.
	-Aadimos la posibilidad de que al crear un orden para una lista de artculos se establezca por encima del de la sesin (se usa en los
		relacionados)
	-Aadidos los campos "base" para cesta de la compra y pedidos. Mostramos el total sin iva de la compra. Adems hacemos que el porcentaje
		de iva se introduzca en las lneas de pedido de manera automtica.
	-Comentamos la funcin que importa categoras-productos porque desde herbolib ya no es necesaria y desde SInlib tampoco.
	-Inicio de sesin desde Google
	-Inicio de sesin desde Facebook
	-Se eliminan todos los widgets de direcciones de envo y se deja slo uno que ser el encargado de mostrar 1 direccin de envo
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 3 (2.8.3)
	-Quitada la clase OpcionesSlider
	-OpcionesWidget se lleva a la carpeta de componentes
	-Se crea la clase nueva Options que es la que se va a usar a partir de ahora para pasar opciones a las funciones
		Dicha funcin va a permitir que se le pase un "OpcionesWidget" u devuelva un Optiones para mejorar la retrocompatibilidad
	-Se crea la opcin de guardar_sesion_al_modificar en la clase de configuracin. Su funcin es que se guarden todas las variables de sesin
		en cada acceso para actualizar la fecha. Produce ms escrituras en la BD, pero hace que no puierdas variables como el login
		cuando es una web de uso diario (un proveedor).
	-Se crea la tabla de datos de envo para el pedido temporal. Se aaden los controles que hacen que al guardar un pedido ste 
		guarde con todos los datos asociados (cliente, envo, etc.)
	-Al hacer login se fusiona la cesta que el usuario tuviese guardada con la que est preparando antes de este login
	-La carga dinmica se hace, ahora utilizando ms elementos para que se recarguen menos cosas en la cesta
	-Se aade el cdigo promocional usado a la cesta y se se aaden los controles necesarios para utilizarlo
	-Aadimos tipo de envo y forma de pago al pedido temporal y definitivo, eliminndolo de la sesin
	-Aadido el hash, la funcin de grabado y el array de campos que se pueden guardar con ellos al objeto para que estn disponibles en todos los elementos
	-Emails envan dos email, uno al usuario y otro a la empresa
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 4 (2.8.4)
	-Aadida opcin de configuracin en empresa del tipo de envo que representa la recogida en tienda
	-Aadido control de versiones en fichero .php
	-Aadida carpeta con los datos a actualizar en cada versin
	-Eliminado el controlador "component"
	-Versin inicial de los mdulos
	-Buscador simple sin javaScript
	2.8.4.1:
		* Buscador avanzado sin javascript
		* Finalizar pedidos cliente de manera asncrona
		* pasarela de pago redsys
	-Mejora de los mdulos, se pueden ejecutar con personalizaciones
	-Se aade un multi-accion para las acciones y se mejora la recogida de estas
	-Se pueden mandar acciones en los parmetros de las funciones remotas
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 5 (2.8.5)
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.8.6)
	-2.8.6.2:
		Desde el timo comentario hasta esta versin se ha perdido la informacin
	-2.8.6.3:
		* Se mejora la bsqueda haciendo que la global sea por palabras mejorando los plurales y singulares y la especfica sea por trozos de palabras
		* Se aade un valor por defecto a los segundos de sesin para que SIEMPRE sean mayores que 0. Se pone por defecto un ao
		* Si no hay valores en la sesin pero tocamos la cesta, metemos un valor "DUMY" en esta para que no borre al hacerse la purga
		* Mejorado mdulo recaptcha, las claves van slo en el mdulo, no hay que personalizar el "action"
		* Cuando se enva un email nos aseguramos de convertir las entidades html a su cdigo real tanto en el asunto como en el contenido.
		* Corregido error : cuando un escaparate no est visible y tiene hijos, falla la generacin del fichero de escaparate
		* Aadido al tema un array de parmetros de configuracin que l mismo podr utilizar para guardar valores
		* Se crea el fichero theme_config.php que, si existe, se cargar antes de empezar a cargar el tema
		* se aade un input hidden al formulario de modificacin de clientes para ponerlos "pendientes_sinlib" a 1
		* Aadido el cdigo a los cdigos promocionales
		* Se aade el cdigo de cliente contado web porque actualmente tenemos slo el cdigo de cliente contado sinlib
		* Corregido problema que mostraba la palabra "traducir" cuando no se activaban el mdulo multi-idioma y el "active_traducction" al mismo tiempo
		* Aadido tema padre a las opciones del tema para agilizar la personalizacin
		* Mejorado sistema de generacin de ficheros CSS
		* Aadadia opcion modo mantenimiento
***** Revisin 6 (2.8.7)		
		* Creadas las zonas de envo con rangos
		* Aadido al controlador del tema la posibilidad de obtener la URL real

==> webStore_2.8.9_estable.zip: README.md <==
***** Version inicial 2.8.0
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 1 (2.8.1)
	- La funcin remota es la encargada de lanzar los widgets a actualizar. Hasta ahora lo haca cada "remoteXxxxxx" de cada clase
		Y eso obligaba al programador a repetir lo mismo SIEMPRE
	- Creada la clase Email con su funcionalidad bsica
	- Clase Email enva emails directamente o desde funcin remota (Ajax)
	- Terminado un apartado de contacto actualizando el widget actual
	- Actualizada clase de usuario para aadir varias funciones estticas:
		1 Chequeo de que el usuario existe utilizando el email
		2 Registro del usuario en la BD
		3 Login de usuario
	- Preparamos una versin previa del registro
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 2 (2.8.2)
	- Creacin de gestin bsica de mdulos (sin admin)
		- Control de acciones ==> las acciones se guardan en un fichero llamado actions.php para cada mdulo.
	-(luna de papel) Se crean mdulos para login, registro y recuperar contrasea. Por ahora slo se registran las aciones
		de dichos mdulos
	-Aadimos a la clase Usuario las funciones necesarias para hacer login, registro y recuperacin de contrasea
	-Aadimos a la clase Sesion una propiedad esttica que consiste en un array dnde guardaremos los pares variable => valor
		y usaremos este arrya cuando haya que recargar la pgina para adir dichas variables como get (?variable=valor)
	-Aadimos los get/insert/delete/isset de dichas variables
	-El control de secciones se hace ahora desde la clase de secciones y no es necesario utilizar el fichero sectionControl
	-La carga dinmica se hace ahora por tema para que la cach sea independiente para cada instancia de webStore
	-Las clases y mtodos se pueden sobre escribir en el tema y en todo webStore
	-Se crean variables para indicar dnde est la carpeta css
	-Se mejora el proceso de minificacin de CSS creando una funcin comn
	-Se crea el tema Admin fuera de la carpeta Themes para administrar WebStore
	-Se crea en Admin la opcin para subir imgenes
	-La subida de datos se almacenar, a partir de ahora en la carpeta update. Dentro de esta carpeta se almacenarn los
		ficheros segn su tipo (imagenes, videos, pdf, etc.)
	-Modificacin en la clase Banner que permite mostrar una imagen independientemente de que est o no en un banner
	-Modificacin en la clase Banner para que se pueda eliminar una imagen siempre que no est en un banner y se le hace un 
		acceso remoto.
	-Aadimos la posibilidad de que al crear un orden para una lista de artculos se establezca por encima del de la sesin (se usa en los
		relacionados)
	-Aadidos los campos "base" para cesta de la compra y pedidos. Mostramos el total sin iva de la compra. Adems hacemos que el porcentaje
		de iva se introduzca en las lneas de pedido de manera automtica.
	-Comentamos la funcin que importa categoras-productos porque desde herbolib ya no es necesaria y desde SInlib tampoco.
	-Inicio de sesin desde Google
	-Inicio de sesin desde Facebook
	-Se eliminan todos los widgets de direcciones de envo y se deja slo uno que ser el encargado de mostrar 1 direccin de envo
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 3 (2.8.3)
	-Quitada la clase OpcionesSlider
	-OpcionesWidget se lleva a la carpeta de componentes
	-Se crea la clase nueva Options que es la que se va a usar a partir de ahora para pasar opciones a las funciones
		Dicha funcin va a permitir que se le pase un "OpcionesWidget" u devuelva un Optiones para mejorar la retrocompatibilidad
	-Se crea la opcin de guardar_sesion_al_modificar en la clase de configuracin. Su funcin es que se guarden todas las variables de sesin
		en cada acceso para actualizar la fecha. Produce ms escrituras en la BD, pero hace que no puierdas variables como el login
		cuando es una web de uso diario (un proveedor).
	-Se crea la tabla de datos de envo para el pedido temporal. Se aaden los controles que hacen que al guardar un pedido ste 
		guarde con todos los datos asociados (cliente, envo, etc.)
	-Al hacer login se fusiona la cesta que el usuario tuviese guardada con la que est preparando antes de este login
	-La carga dinmica se hace, ahora utilizando ms elementos para que se recarguen menos cosas en la cesta
	-Se aade el cdigo promocional usado a la cesta y se se aaden los controles necesarios para utilizarlo
	-Aadimos tipo de envo y forma de pago al pedido temporal y definitivo, eliminndolo de la sesin
	-Aadido el hash, la funcin de grabado y el array de campos que se pueden guardar con ellos al objeto para que estn disponibles en todos los elementos
	-Emails envan dos email, uno al usuario y otro a la empresa
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 4 (2.8.4)
	-Aadida opcin de configuracin en empresa del tipo de envo que representa la recogida en tienda
	-Aadido control de versiones en fichero .php
	-Aadida carpeta con los datos a actualizar en cada versin
	-Eliminado el controlador "component"
	-Versin inicial de los mdulos
	-Buscador simple sin javaScript
	2.8.4.1:
		* Buscador avanzado sin javascript
		* Finalizar pedidos cliente de manera asncrona
		* pasarela de pago redsys
	-Mejora de los mdulos, se pueden ejecutar con personalizaciones
	-Se aade un multi-accion para las acciones y se mejora la recogida de estas
	-Se pueden mandar acciones en los parmetros de las funciones remotas
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 5 (2.8.5)
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.8.6)
	-2.8.6.2:
		Desde el timo comentario hasta esta versin se ha perdido la informacin
	-2.8.6.3:
		* Se mejora la bsqueda haciendo que la global sea por palabras mejorando los plurales y singulares y la especfica sea por trozos de palabras
		* Se aade un valor por defecto a los segundos de sesin para que SIEMPRE sean mayores que 0. Se pone por defecto un ao
		* Si no hay valores en la sesin pero tocamos la cesta, metemos un valor "DUMY" en esta para que no borre al hacerse la purga
		* Mejorado mdulo recaptcha, las claves van slo en el mdulo, no hay que personalizar el "action"
		* Cuando se enva un email nos aseguramos de convertir las entidades html a su cdigo real tanto en el asunto como en el contenido.
		* Corregido error : cuando un escaparate no est visible y tiene hijos, falla la generacin del fichero de escaparate
		* Aadido al tema un array de parmetros de configuracin que l mismo podr utilizar para guardar valores
		* Se crea el fichero theme_config.php que, si existe, se cargar antes de empezar a cargar el tema
		* se aade un input hidden al formulario de modificacin de clientes para ponerlos "pendientes_sinlib" a 1
		* Aadido el cdigo a los cdigos promocionales
		* Se aade el cdigo de cliente contado web porque actualmente tenemos slo el cdigo de cliente contado sinlib
		* Corregido problema que mostraba la palabra "traducir" cuando no se activaban el mdulo multi-idioma y el "active_traducction" al mismo tiempo
		* Aadido tema padre a las opciones del tema para agilizar la personalizacin
		* Mejorado sistema de generacin de ficheros CSS
		* Aadida opcion modo mantenimiento
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.8.7)
		* Creadas las zonas de envo con rangos
		* Aadido al controlador del tema la posibilidad de obtener la URL real
		* Correccin en los mdulos, son completamente personalizables en el tema. Antes daban error al ejecutarse las funciones remotas
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.8.8)
		* Optimizaciones de la clase Articulo
		* Carga del artculo padre como un objeto dentro de un hijos
		* Corregido bug en clase "Usuario": Al utilizar el password encriptado antiguo(sha1), el registro y el login no se codificaban igual as que no hacia login.
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.8.9)
        * Corregido bug en calse "Usuario": Cuando se coge, en la zona la direccin de envo, se coge la predeterminada. Sin embargo la cesta no actualiza esa direccin si se cambia
		*	por tanto si un cliente crea primero una direccin no permitida y luego una permitida, ya no puede comprar
		* La clase "Email" estaba enviando los emails con el mtodo "mail" nativo de PHP. Es por ello que pasaba olmpicamente del servidor que se estuviese utilizando.
		*	Para esta correccin se ha actualizado la librera phpMailer y se ha aadido en su carpeta un "loader" que se encarga de hacer los includes necesarios
		* Cuando se hace un pedido por transferencia sin registro, se queda la pgina en blanco => Solucionado un problema de recursividad. A partir de ahora la funcin getCode
		*	de la cesta guarda la cesta en la esttica si sta est vaca.
------------------------------------------------------------------------------------------------------------------------------------------
***** Revisin 6 (2.9.00)
		*
